gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[gnunet] 54/90: -DOC: Documentation cleanup pass through TESTBED subsyst


From: gnunet
Subject: [gnunet] 54/90: -DOC: Documentation cleanup pass through TESTBED subsystem
Date: Tue, 18 Oct 2022 03:06:53 +0200

This is an automated email from the git hooks/post-receive script.

martin-schanzenbach pushed a commit to branch master
in repository gnunet.

commit 42cda6099b5957ab28f19a7b793a5428c96faeb8
Author: Willow Liquorice <willow@howhill.com>
AuthorDate: Wed Sep 7 21:20:48 2022 +0100

    -DOC: Documentation cleanup pass through TESTBED subsystem
---
 src/testbed/gnunet-service-testbed.c          |  4 ++--
 src/testbed/gnunet-service-testbed.h          |  2 +-
 src/testbed/gnunet-service-testbed_barriers.c |  4 ++--
 src/testbed/testbed_api.c                     | 28 +++++++++++++--------------
 src/testbed/testbed_api_hosts.c               |  1 -
 5 files changed, 19 insertions(+), 20 deletions(-)

diff --git a/src/testbed/gnunet-service-testbed.c 
b/src/testbed/gnunet-service-testbed.c
index 91aa5dd88..b2f04d5d8 100644
--- a/src/testbed/gnunet-service-testbed.c
+++ b/src/testbed/gnunet-service-testbed.c
@@ -379,7 +379,7 @@ parse_shared_services (char *ss_str,
  * Check #GNUNET_MESSAGE_TYPE_TESTBED_INIT messages
  *
  * @param cls identification of the client
- * @param message the actual message
+ * @param msg the actual message
  * @return #GNUNET_OK if @a message is well-formed
  */
 static int
@@ -404,7 +404,7 @@ check_init (void *cls,
  * Message handler for #GNUNET_MESSAGE_TYPE_TESTBED_INIT messages
  *
  * @param cls identification of the client
- * @param message the actual message
+ * @param msg the actual message
  */
 static void
 handle_init (void *cls,
diff --git a/src/testbed/gnunet-service-testbed.h 
b/src/testbed/gnunet-service-testbed.h
index 920e22f05..67dfbf253 100644
--- a/src/testbed/gnunet-service-testbed.h
+++ b/src/testbed/gnunet-service-testbed.h
@@ -701,7 +701,7 @@ handle_peer_start (void *cls,
  * Message handler for #GNUNET_MESSAGE_TYPE_TESTBED_DESTROYPEER messages
  *
  * @param cls identification of the client
- * @param message the actual message
+ * @param msg the actual message
  */
 void
 handle_peer_stop (void *cls,
diff --git a/src/testbed/gnunet-service-testbed_barriers.c 
b/src/testbed/gnunet-service-testbed_barriers.c
index be33bd131..bc6148087 100644
--- a/src/testbed/gnunet-service-testbed_barriers.c
+++ b/src/testbed/gnunet-service-testbed_barriers.c
@@ -328,7 +328,7 @@ send_barrier_status_msg (struct Barrier *barrier,
  * Check #GNUNET_MESSAGE_TYPE_TESTBED_BARRIER_WAIT messages.
  *
  * @param cls identification of the client
- * @param message the actual message
+ * @param msg the actual message
  */
 static int
 check_barrier_wait (void *cls,
@@ -347,7 +347,7 @@ check_barrier_wait (void *cls,
  * either from the testbed driver or from a high level controller
  *
  * @param cls identification of the client
- * @param message the actual message
+ * @param msg the actual message
  */
 static void
 handle_barrier_wait (void *cls,
diff --git a/src/testbed/testbed_api_hosts.c b/src/testbed/testbed_api_hosts.c
index e0c48f709..824bd0187 100644
--- a/src/testbed/testbed_api_hosts.c
+++ b/src/testbed/testbed_api_hosts.c
@@ -918,7 +918,6 @@ gen_rsh_suffix_args (const char *const *append_args)
  * Do not call GNUNET_SERVER_mst_destroy in callback
  *
  * @param cls closure
- * @param client identification of the client
  * @param message the actual message
  *
  * @return #GNUNET_OK on success, #GNUNET_SYSERR to stop further processing

diff --git a/src/testbed/testbed_api.c b/src/testbed/testbed_api.c
index 46b8ab901..2ae0a1703 100644
--- a/src/testbed/testbed_api.c
+++ b/src/testbed/testbed_api.c
@@ -407,7 +407,7 @@ handle_add_host_confirm (void *cls,
 /**
  * Handler for forwarded operations
  *
- * @param c the controller handle
+ * @param cls the controller handle
  * @param opc the operation context
  * @param msg the message
  */
@@ -432,7 +432,7 @@ handle_forwarded_operation_msg (void *cls,
  * Handler for #GNUNET_MESSAGE_TYPE_TESTBED_ADD_HOST_SUCCESS message from
  * controller (testbed service)
  *
- * @param c the controller handler
+ * @param cls the controller handler
  * @param msg message received
  */
 static void
@@ -536,7 +536,7 @@ handle_opsuccess (
  * Handler for #GNUNET_MESSAGE_TYPE_TESTBED_CREATE_PEER_SUCCESS message from
  * controller (testbed service)
  *
- * @param c the controller handle
+ * @param cls the controller handle
  * @param msg message received
  */
 static void
@@ -594,7 +594,7 @@ handle_peer_create_success (
  * Handler for #GNUNET_MESSAGE_TYPE_TESTBED_PEER_EVENT message from
  * controller (testbed service)
  *
- * @param c the controller handler
+ * @param cls the controller handler
  * @param msg message received
  */
 static void
@@ -675,7 +675,7 @@ handle_peer_event (void *cls, const struct 
GNUNET_TESTBED_PeerEventMessage *msg)
  * Handler for #GNUNET_MESSAGE_TYPE_TESTBED_PEER_CONNECT_EVENT message from
  * controller (testbed service)
  *
- * @param c the controller handler
+ * @param cls the controller handler
  * @param msg message received
  */
 static void
@@ -751,7 +751,7 @@ handle_peer_conevent (void *cls,
  * Validate #GNUNET_MESSAGE_TYPE_TESTBED_PEER_INFORMATION message from
  * controller (testbed service)
  *
- * @param c the controller handler
+ * @param cls the controller handler
  * @param msg message received
  */
 static int
@@ -768,7 +768,7 @@ check_peer_config (
  * Handler for #GNUNET_MESSAGE_TYPE_TESTBED_PEER_INFORMATION message from
  * controller (testbed service)
  *
- * @param c the controller handler
+ * @param cls the controller handler
  * @param msg message received
  */
 static void
@@ -840,7 +840,7 @@ handle_peer_config (
  * Validate #GNUNET_MESSAGE_TYPE_TESTBED_OPERATION_FAIL_EVENT message from
  * controller (testbed service)
  *
- * @param c the controller handler
+ * @param cls the controller handler
  * @param msg message received
  * @return #GNUNET_OK if message is well-formed
  */
@@ -858,7 +858,7 @@ check_op_fail_event (
  * Handler for #GNUNET_MESSAGE_TYPE_TESTBED_OPERATION_FAIL_EVENT message from
  * controller (testbed service)
  *
- * @param c the controller handler
+ * @param cls the controller handler
  * @param msg message received
  */
 static void
@@ -1037,7 +1037,7 @@ check_slave_config (void *cls,
  * Handler for #GNUNET_MESSAGE_TYPE_TESTBED_SLAVE_CONFIGURATION message from 
controller
  * (testbed service)
  *
- * @param c the controller handler
+ * @param cls the controller handler
  * @param msg message received
  */
 static void
@@ -1099,7 +1099,7 @@ check_link_controllers_result (
  * Handler for #GNUNET_MESSAGE_TYPE_TESTBED_LINK_CONTROLLERS_RESULT message 
from controller
  * (testbed service)
  *
- * @param c the controller handler
+ * @param cls the controller handler
  * @param msg message received
  */
 static void
@@ -2384,7 +2384,7 @@ GNUNET_TESTBED_barrier_init_ (struct 
GNUNET_TESTBED_Controller *controller,
  *   GNUNET_TESTBED_barrier_reached().
  * @param cb the callback to call when the barrier is reached or upon error.
  *   Cannot be NULL.
  * @param cls closure for the above callback
  * @return barrier handle; NULL upon error
  */
 struct GNUNET_TESTBED_Barrier *
@@ -2392,13 +2392,13 @@ GNUNET_TESTBED_barrier_init (struct 
GNUNET_TESTBED_Controller *controller,
                              const char *name,
                              unsigned int quorum,
                              GNUNET_TESTBED_barrier_status_cb cb,
-                             void *cls)
+                             void *cb_cls)
 {
   return GNUNET_TESTBED_barrier_init_ (controller,
                                        name,
                                        quorum,
                                        cb,
-                                       cls,
+                                       cb_cls,
                                        GNUNET_YES);
 }
 
@@ -2384,7 +2384,7 @@ GNUNET_TESTBED_barrier_init_ (struct 
  * @param cb the callback to call when the barrier is reached or upon error.
  *   Cannot be NULL.
- * @param cls closure for the above callback
+ * @param cb_cls closure for the above callback
  * @return barrier handle; NULL upon error
  */
-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]